@@ -6,7 +6,7 @@ def social_details(backend, details, response, *args, **kwargs):
 
 
 def social_uid(backend, details, response, *args, **kwargs):
-    return {"uid": backend.get_user_id(details, response)}
+    return {"uid": str(backend.get_user_id(details, response))}
 
 
 def auth_allowed(backend, details, response, *args, **kwargs):
